@@ -39,16 +39,16 @@
 //     2a) If there are no matching flags, do nothing.
 //     2b) If all matching flags share a common prefix longer than the
 //         completion word, output just that matching prefix
-//  3) Categorize those flags to produce a rough ordering of relevence.
+//  3) Categorize those flags to produce a rough ordering of relevance.
 //  4) Potentially trim the set of flags returned to a smaller number
 //     that bash is happier with
-//  5) Output the matching flags in groups ordered by relevence.
+//  5) Output the matching flags in groups ordered by relevance.
 //     5a) Force bash to place most-relevent groups at the top of the list
 //     5b) Trim most flag's descriptions to fit on a single terminal line
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>   // for strlen
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>   // for strlen
 
 #include <set>
 #include <string>
@@ -170,7 +170,7 @@ static string GetLongFlagLine(
 //    most likely to be useful first.  If this is set, however, the user
 //    really does want us to return every single flag as an option.
 //  - force_no_update: Any time we output lines, all of which share a
-//    common prefix, bash will 'helpfully' not even bother to show the
+//    common prefix, bash will 'helpfuly' not even bother to show the
 //    output, instead changing the current word to be that common prefix.
 //    If it's clear this shouldn't happen, we'll set this boolean
 struct CompletionOptions {
@@ -188,7 +188,7 @@ struct CompletionOptions {
 
 // Notable flags are flags that are special or preferred for some
 // reason.  For example, flags that are defined in the binary's module
-// are expected to be much more relevent than flags defined in some
+// are expected to be much more relevant than flags defined in some
 // other random location.  These sets are specified roughly in precedence
 // order.  Once a flag is placed in one of these 'higher' sets, it won't
 // be placed in any of the 'lower' sets.
@@ -325,12 +325,10 @@ static void CanonicalizeCursorWordAndSearchOptions(
     }
     break;
   }
-
-  switch (found_question_marks) {  // all fallthroughs
-    case 3: options->flag_description_substring_search = true;
-    case 2: options->flag_location_substring_search = true;
-    case 1: options->flag_name_substring_search = true;
-  };
+  
+  if (found_question_marks > 2) options->flag_description_substring_search = true;
+  if (found_question_marks > 1) options->flag_location_substring_search = true;
+  if (found_question_marks > 0) options->flag_name_substring_search = true;
 
   options->return_all_matching_flags = (found_plusses > 0);
 }
@@ -412,7 +410,7 @@ static bool DoesSingleFlagMatch(
 // 3) Categorize matches (and helper method)
 
 // Given a set of matching flags, categorize them by
-// likely relevence to this specific binary
+// likely relevance to this specific binary
 static void CategorizeAllMatchingFlags(
     const set<const CommandLineFlagInfo *> &all_matches,
     const string &search_token,
@@ -453,10 +451,6 @@ static void CategorizeAllMatchingFlags(
       // In the package, since there was no slash after the package portion
       notable_flags->package_flags.insert(*it);
       DVLOG(3) << "Result: package match";
-    } else if (false) {
-      // In the list of the XXX most commonly supplied flags overall
-      // TODO(user): Compile this list.
-      DVLOG(3) << "Result: most-common match";
     } else if (!package_dir.empty() &&
         pos != string::npos && slash != string::npos) {
       // In a subdirectory of the package
